@@ -89,12 +89,13 @@ def pluralize(
 
 
 def coalesce(*values: Optional[T]) -> Optional[T]:
-    """Returns the first value that is not None (or None if no such value exists)."""
+    """Return the first value that is not ``None``
+    (or ``None`` if no such value exists)."""
     return next((val for val in values if val is not None), None)
 
 
 def first_bool(*values: Any) -> bool:
-    """Returns the first bool (or raises StopIteration if no bool is found)."""
+    """Return the first bool (or raises ``StopIteration`` if no bool is found)."""
     return next(val for val in values if isinstance(val, bool))
 
 
@@ -125,7 +126,13 @@ class FrozenSpaceMeta(type):
         type.__setattr__(cls, '_dict', d)
 
     def __setattr__(cls, key: str, value: Any) -> None:
-        raise Exception("you can't set attributes on this class")
+        if key.startswith("__"):
+            return super().__setattr__(key, value)
+        else:
+            raise Exception(
+                "you can't set attributes on this class; only special dunder attributes "
+                "(e.g. __annotations__) are allowed to be set for compatibility reasons."
+            )
 
     def asdict(cls) -> Dict[str, Any]:
         return cls._dict  # type: ignore
